@@ -5,11 +5,15 @@ Overview
 It is used to remember an important position of the text and quickly switch to it.
 
 
+Usage
+=====
+
+When <Key-space> is pressed in NORMAL mode then a mark is dropped at the cursor position. It is possible to set the cursor back to that
+mark by pressing <BackSpace> in NORMAL mode.
+
 Key-Commands
 ============
 
-Namespace: quick-jumps
-
 Mode: NORMAL
 Event: 
 Description: 
@@ -20,14 +24,11 @@ Description:
 
 """
 
-class QuickJumps:
+class QuickJumps(object):
     def __init__(self, area):
         self.area  = area
-        area.install('quick-jumps', ('NORMAL', '<Key-space>', lambda event: self.area.mark_set('(PREV_POSITION)', 'insert')),
+        area.install(('NORMAL', '<Key-space>', lambda event: self.area.mark_set('(PREV_POSITION)', 'insert')),
                      ('NORMAL', '<BackSpace>', lambda event: self.area.seecur('(PREV_POSITION)')))
 
 install = QuickJumps
 
-
-
-
